TypographyBreakpoint class
Constructors
- TypographyBreakpoint({required TypographyData overrides, double minWidth = 0, double maxWidth = double.infinity})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxWidth → double
-
final
- minWidth → double
-
final
- overrides → TypographyData
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited